
function a = feature_warp(N,signal)

% Function to return warped features based on algorithm from the
% paper : Feature Warping for Robust Speaker Verification by
% Jason Pelecanos and Sridha Sridharan, 2001
%
% N is window width in number of features(MFCC, PLP) and could be seconds long(usually 3 sec).
% It also have to be an odd number for simplicity.
% signal is an array(not matrix) of MFCC,PLP features
% Return the new warped feature based on a gaussian distribution

% Author Tommy Strmhaug,2008

% New array will have same length as input due to padding

% Check if number is odd
if mod(N,2)==0
    error('N must be odd');
end

centerFeat = ceil(N/2);

%pad signal in a circular fashion
signal=signal;
padlength = centerFeat-1;
length(signal);
%pause(inf)

left=signal(1:padlength);
right=signal(end-padlength+1:end);
signal=cat(1,left,signal);
signal=cat(1,signal,right);

%Allocate new feature array for faster execution
%feats = zeros(1,length(signal));

for i=1:length(signal)-N+1

    %Find rank of center
    centerNumber = signal(i+centerFeat-1);
    % Current window
    %temparray=signal(i:(N-1)+i)
    %Sort array
    temparray=sort(signal(i:(N-1)+i),'descend');
    %Find rank of center window in the sorted list
    rank = find(temparray==centerNumber,1);

    feats(i)=warp(rank,N);

end
%dimesnion

a=feats;

x = -2.9:0.1:2.9;

%plot histogram
%hist(feats,40);

function b=warp(R,N)

%Function to make gaussian distributin

% Gaussian expression to warp to
%h = (1/sqrt(2*pi))*exp(-x^(2)/2);

% Solving the integral equation with respect to upper
% bound of integral. This is equation (5) in the paper.

x1 = norminv((N+0.5-R)/(N),0,1);
b=x1;
%b=solve((int(h,-inf,r)-((N+0.5-R)/(N))))


